::: neurogym.envs.registration
::: neurogym.envs.native.annubes
::: neurogym.envs.native.antireach
::: neurogym.envs.native.bandit
::: neurogym.envs.native.contextdecisionmaking
::: neurogym.envs.native.dawtwostep
::: neurogym.envs.native.delaycomparison
::: neurogym.envs.native.delaymatchcategory
::: neurogym.envs.native.delaymatchsample
::: neurogym.envs.native.delaypairedassociation
::: neurogym.envs.native.detection
::: neurogym.envs.native.dualdelaymatchsample
::: neurogym.envs.native.economicdecisionmaking
::: neurogym.envs.native.gonogo
::: neurogym.envs.native.hierarchicalreasoning
::: neurogym.envs.native.intervaldiscrimination
::: neurogym.envs.native.multisensory
::: neurogym.envs.native.null
::: neurogym.envs.native.perceptualdecisionmaking
::: neurogym.envs.native.postdecisionwager
::: neurogym.envs.native.probabilisticreasoning
::: neurogym.envs.native.reaching
::: neurogym.envs.native.reachingdelayresponse
::: neurogym.envs.native.readysetgo
::: neurogym.envs.native.spatialsuppressmotion
::: neurogym.envs.native.tonedetection
